@@ -14,8 +14,19 @@ This file includes most of the needed system headers.
 */
 
 /*
- * $Id: includes.h,v 1.9 1997/03/19 18:02:19 kivinen Exp $
+ * $Id: includes.h,v 1.12 1998/04/30 01:51:53 kivinen Exp $
  * $Log: includes.h,v $
+ * Revision 1.12  1998/04/30 01:51:53  kivinen
+ * 	Added linux sparc fix.
+ *
+ * Revision 1.11  1998/01/21 14:01:11  kivinen
+ * 	Fixed bug raported Paul J. Sanchez <paul@spectrum.slu.edu>
+ * 	about S_ISLNK macro defination.
+ *
+ * Revision 1.10  1998/01/02 06:18:20  kivinen
+ * 	Added sys/resource.h include. Added _S_IFLNK and S_ISLNK
+ * 	defines if not defined by system.
+ *
  * Revision 1.9  1997/03/19 18:02:19  kivinen
  * 	Added SECURE_RPC, SECURE_NFS and NIS_PLUS support from Andy
  * 	Polyakov <appro@fy.chalmers.se>.
@@ -150,8 +161,12 @@ YOU_LOSE
 #include <signal.h>
 
 #ifdef sparc
+#ifdef linux
+#undef HAVE_UTMPX_H
+#else
 #undef HAVE_SYS_IOCTL_H
 #endif
+#endif
 
 #ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
@@ -283,6 +298,10 @@ struct linger {
 #endif /* HAVE_SYS_TIME_H */
 #endif /* TIME_WITH_SYS_TIME */
 
+#if HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#endif
+
 #ifdef HAVE_PATHS_H
 #include <paths.h>
 #endif
@@ -338,6 +357,12 @@ struct linger {
 #ifndef _S_IFDIR
 #define _S_IFDIR 0040000
 #endif
+#ifndef _S_IFLNK
+#define _S_IFLNK 0120000
+#endif
+#ifndef S_ISLNK
+#define S_ISLNK(mode) (((mode)&(_S_IFMT))==(_S_IFLNK))
+#endif
 
 #if USE_STRLEN_FOR_AF_UNIX
 #define AF_UNIX_SIZE(unaddr) \
