@@ -8,19 +8,36 @@ Copyright (c) 1995 Tatu Ylonen <ylo@cs.hut.fi>, Espoo, Finland
                    All rights reserved
 
 Created: Mon Mar 20 21:23:10 1995 ylo
-Last modified: Fri Jun 23 19:52:22 1995 ylo
 
 Versions of malloc and friends that check their results, and never return
 failure (they call fatal if they encounter an error).
 
 */
 
+/*
+ * $Id: xmalloc.c,v 1.1.1.1 1996/02/18 21:38:11 ylo Exp $
+ * $Log: xmalloc.c,v $
+ * Revision 1.1.1.1  1996/02/18 21:38:11  ylo
+ * 	Imported ssh-1.2.13.
+ *
+ * Revision 1.3  1995/08/29  22:36:39  ylo
+ * 	Commented out malloc prototypes.
+ *
+ * Revision 1.2  1995/07/13  01:41:33  ylo
+ * 	Removed "Last modified" header.
+ * 	Added cvs log.
+ *
+ * $Endlog$
+ */
+
 #include "includes.h"
 #include "ssh.h"
 
+#if 0
 void *malloc(size_t size);
 void *realloc(void *ptr, size_t size);
 void free(void *ptr);
+#endif
 
 void *xmalloc(size_t size)
 {
